from __future__ import annotations

from ..l0.Characteristic import Characteristic
from ..ns import *


class TransparencyDataTypology(Characteristic):
    __type__ = TRANSP["TransparencyDataTypology"]
