from .AcademicDiscipline import AcademicDiscipline
from .AcademicRecruitementField import AcademicRecruitementField
from .Area import Area
from .HERClassification import HERClassification
from .MacroSector import MacroSector
from .ScientificDisciplinarySector import ScientificDisciplinarySector
