from .AlivePerson import AlivePerson
from .BornDead import BornDead
from .Dead import Dead
from .EducationLevel import EducationLevel
from .Family import Family
from .FamilySheetHolder import FamilySheetHolder
from .Female import Female
from .ForeignCitizen import ForeignCitizen
from .ItalianCitizen import ItalianCitizen
from .Male import Male
from .NotResident import NotResident
from .ParentalRelationshipType import ParentalRelationshipType
from .Person import Person
from .PersonTitle import PersonTitle
from .RegisteredFamily import RegisteredFamily
from .ResidenceInTime import ResidenceInTime
from .Resident import Resident
from .Sex import Sex
from .Stateless import Stateless