from .AmendmentDocument import AmendmentDocument
from .AmendmentRationale import AmendmentRationale
from .Award import Award
from .AwardCriterion import AwardCriterion
from .AwardNotice import AwardNotice
from .CallForCompetition import CallForCompetition
from .Concession import Concession
from .Contract import Contract
from .CommonProcurementVocabulary import CommonProcurementVocabulary
from .DirectAdministration import DirectAdministration
from .Document import Document
from .EconomicSummary import EconomicSummary
from .FrameworkAgreement import FrameworkAgreement
from .Inspection import Inspection
from .Lot import Lot
from .Notice import Notice
from .NoticeType import NoticeType
from .Payment import Payment
from .PaymentCertificate import PaymentCertificate
from .Procedure import Procedure
from .ProcedureChangeEvent import ProcedureChangeEvent
from .ProcedureType import ProcedureType
from .ProcurementDocument import ProcurementDocument
from .ProcurementProject import ProcurementProject
from .Publication import Publication
from .PublicPrivatePartnership import PublicPrivatePartnership
from .PublicProcurement import PublicProcurement
from .Resolution import Resolution
from .ResolutionDocument import ResolutionDocument
from .ResolutionReason import ResolutionReason
from .ResolutionToContract import ResolutionToContract
from .Suspension import Suspension
from .SuspensionDocument import SuspensionDocument
from .SuspensionReason import SuspensionReason
from .Tender import Tender
from .TenderDocument import TenderDocument
from .TenderSubmission import TenderSubmission
from .Variant import Variant
from .VariantDocument import VariantDocument
from .VariantReason import VariantReason
from .WorkProgressReport import WorkProgressReport
