from __future__ import annotations

from ..ns import *
from .CulturalInstituteOrSite import CulturalInstituteOrSite


class ArchaeologicalArea(CulturalInstituteOrSite):
    __type__ = CIS["ArchaeologicalArea"]
