from __future__ import annotations

from ..ns import *
from .CulturalInstituteOrSite import CulturalInstituteOrSite


class HolderOfArchive(CulturalInstituteOrSite):
    __type__ = CIS["HolderOfArchive"]
