from .Accommodation import Accommodation
from .AccommodationChain import AccommodationChain
from .AccommodationRoom import AccommodationRoom
from .AccommodationStarRating import AccommodationStarRating
from .AccommodationTypology import AccommodationTypology
from .Bedroom import Bedroom
from .DoubleRoom import DoubleRoom
from .MeetingRoom import MeetingRoom
from .OfferedServiceDescription import OfferedServiceDescription
from .OSDCriterion import OSDCriterion
from .OSDFeature import OSDFeature
from .QuadrupleRoom import QuadrupleRoom
from .SingleRoom import SingleRoom
from .Suite import Suite
from .TripleRoom import TripleRoom