from __future__ import annotations

from ..ns import *
from .AcademicDiscipline import AcademicDiscipline


class ScientificDisciplinarySector(AcademicDiscipline):
    __type__ = HER["ScientificDisciplinarySector"]
