from __future__ import annotations

from ..ns import *
from .PublicInvestmentProject import PublicInvestmentProject


class ProcurementProject(PublicInvestmentProject):
    __type__ = PROJ["ProcurementProject"]
