from __future__ import annotations

from ..ns import *
from .TransparencyActivity import TransparencyActivity


class TransparencyUpdateActivity(TransparencyActivity):
    __type__ = TRANSP["TransparencyUpdateActivity"]
